ulimit

For platform.

Set or get resource usage limits.

Command Type

built-in

Signature

> ulimit {flags} (limit)

Flags

  • --soft, -S: Sets soft resource limit.
  • --hard, -H: Sets hard resource limit.
  • --all, -a: Prints all current limits.
  • --core-size, -c: Maximum size of core files created
  • --data-size, -d: Maximum size of a process’s data segment
  • --file-size, -f: Maximum size of files created by the shell
  • --file-descriptor-count, -n: Maximum number of open file descriptors
  • --stack-size, -s: Maximum stack size
  • --cpu-time, -t: Maximum amount of CPU time in seconds
  • --virtual-memory-size, -v: Maximum amount of virtual memory available to each process

Parameters

  • limit: The limit value to set.

Input/output types:

input output
nothing any

Examples

Print all current limits.

> ulimit -a

Print specified limits.

> ulimit --core-size --data-size --file-size

Set limit.

> ulimit --core-size 102400

Set stack size soft limit.

> ulimit -s -S 10240

Set virtual memory size hard limit.

> ulimit -v -H 10240

Set core size limit to unlimited.

> ulimit -c unlimited

Ported from nushell/nushell.github.io. Copyright (c) 2021 Nushell Project. MIT License.